<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package MagazineX
 * @since   1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

if ( ! function_exists( 'magazinex_primary_menu_class' ) ) :
	/**
	 * Adds css classes into primary menu
	 *
	 * @param string $class css classname.
	 */
	function magazinex_primary_menu_class( $class = '' ) {

		$classes = array();

		$classes = array_map( 'esc_attr', $classes );

		$classes = apply_filters( 'magazinex_primary_menu_class', $classes, $class );
		$classes = array_unique( $classes );

		echo join( ' ', $classes ); // WPCS: XSS ok.

	}
endif;

if ( ! function_exists( 'mzx_header_actions_container_class' ) ) :
	/**
	 * Adds css classes into primary menu
	 *
	 * @param string $class css classname.
	 */
	function mzx_header_actions_container_class( $class = '' ) {

		$classes = array();

		$classes = array_map( 'esc_attr', $classes );

		$classes = apply_filters( 'mzx_header_actions_container_class', $classes, $class );
		$classes = array_unique( $classes );

		echo join( ' ', $classes ); // WPCS: XSS ok.

	}
endif;

if ( ! function_exists( 'magazinex_body_classes' ) ) :

	/**
	 * Adds custom classes to the array of body classes.
	 *
	 * @param array $classes Classes for the body element.
	 *
	 * @return array
	 */
	function magazinex_body_classes( $classes ) {

		// Adds a class of hfeed to non-singular pages.
		if ( ! is_singular() ) {
			$classes[] = 'hfeed';
		}

		if ( ! is_page_template( 'page-templates/template-magazinex-page-builder.php' ) ) {
			$classes[] = 'mzx-sidebar-layout--' . magazinex_get_current_layout();
		} else {
			$classes[] = 'mzx-sidebar-layout--no-sidebar';
		}

		return $classes;
	}

	add_filter( 'body_class', 'magazinex_body_classes' );
endif;

if ( ! function_exists( 'magazinex_main_header_classes' ) ) :

	/**
	 * Add classes to the posts wrapper.
	 *
	 * @param array $classes Posts wrapper classnames.
	 *
	 * @return array
	 */
	function magazinex_main_header_classes( $classes ) {

		$layout = get_theme_mod( 'magazinex_main_header_layout', 'layout-1' );

		if ( 'layout-1' === $layout ) {
			$style = get_theme_mod( 'magazinex_main_header_layout_1_style', 'style-1' );
		} else {
			$style = get_theme_mod( 'magazinex_main_header_layout_2_style', 'style-1' );
		}

		$classes[] = "mzx-primary-header--{$layout} mzx-primary-header--{$layout}-{$style}";

		return $classes;
	}

	add_filter( 'magazinex_main_header_classes', 'magazinex_main_header_classes' );
endif;

if ( ! function_exists( 'magazinex_pingback_header' ) ) :

	/**
	 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
	 */
	function magazinex_pingback_header() {

		if ( is_singular() && pings_open() ) {
			printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
		}
	}

	add_action( 'wp_head', 'magazinex_pingback_header' );
endif;

if ( ! function_exists( 'magazinex_get_current_layout' ) ) :

	/**
	 * Get the current layout of the page
	 *
	 * @return string layout.
	 */
	function magazinex_get_current_layout() {

		$default_layout = get_theme_mod( 'magazinex_default_sidebar_layout', 'right' );

		if ( magazinex_is_magazinex_pro_active() ) {
			$layout = apply_filters( 'magazinex_pro_current_layout', '' );
		} else {
			switch ( true ) {

				case ( is_singular( 'page' ) || is_404() ):
					$page_layout = get_theme_mod( 'magazinex_page_sidebar_layout', 'default' );
					$layout      = 'default' !== $page_layout ? $page_layout : $default_layout;

					break;

				case ( is_singular() ):
					$page_layout = get_theme_mod( 'magazinex_single_post_sidebar_layout', 'default' );
					$layout      = 'default' !== $page_layout ? $page_layout : $default_layout;

					break;

				case ( is_archive() || is_home() ):
					$page_layout = get_theme_mod( 'magazinex_archive_sidebar_layout', 'default' );
					$layout      = 'default' !== $page_layout ? $page_layout : $default_layout;

					break;

				default:
					$layout = get_theme_mod( 'magazinex_default_sidebar_layout', 'right' );
			}
		}

		return apply_filters( 'magazinex_current_layout', $layout );
	}
endif;

if ( ! function_exists( 'magazinex_add_submenu_icon' ) ) :

	/**
	 * Add submenu icon after the menu title.
	 *
	 * @param string $item_output The menu item's starting HTML output.
	 * @param WP_Post $item Menu item data object.
	 * @param int $depth Depth of menu item. Used for padding.
	 * @param stdClass $args An object of wp_nav_menu() arguments.
	 *
	 * @return array|mixed|string|string[]
	 * @since 1.0.0
	 *
	 */
	function magazinex_add_submenu_icon( $item_output, $item, $depth, $args ) {

		if (
			'mzx-menu-primary' === $args->theme_location
		) {

			if (
				in_array( 'menu-item-has-children', $item->classes, true ) ||
				in_array( 'page_item_has_children', $item->classes, true )
			) {
				$item_output = str_replace(
					$args->link_after . '</a>',
					$args->link_after . '</a><span role="button" tabindex="0" class="mzx-submenu-toggle" onkeypress="">' . magazinex_get_icon( 'arrow-down', false ) . '</span>',
					$item_output
				);
			}
		}

		return $item_output;
	}

	add_filter( 'walker_nav_menu_start_el', 'magazinex_add_submenu_icon', 10, 4 );
endif;

if ( ! function_exists( 'magazinex_get_icon' ) ) :

	/**
	 * Get SVG icon.
	 *
	 * @param string $icon Default is empty.
	 * @param bool $echo Default is true.
	 * @param array $args Default is empty.
	 *
	 * @return string|null
	 */
	function magazinex_get_icon( $icon = '', $echo = true, $args = array() ) {
		return MagazineX_SVG_Icons::get_svg( $icon, $echo, $args );
	}
endif;

if ( ! function_exists( 'mzx_header_bar_widget_container_class' ) ) :
	/**
	 * Adds css classes into the header_bar widget area
	 *
	 * @param string $class css classname.
	 */
	function mzx_header_bar_widget_container_class( $class = '' ) {

		$classes = array();

		$classes = array_map( 'esc_attr', $classes );

		$classes = apply_filters( 'mzx_header_bar_widget_container_class', $classes, $class );
		$classes = array_unique( $classes );

		echo join( ' ', $classes ); // WPCS: XSS ok.

	}
endif;

if ( ! function_exists( 'mzx_footer_widget_container_class' ) ) :
	/**
	 * Adds css classes into the footer widget area
	 *
	 * @param string $class css classname.
	 */
	function mzx_footer_widget_container_class( $class = '' ) {

		$classes = array();

		$classes = array_map( 'esc_attr', $classes );

		$classes = apply_filters( 'mzx_footer_widget_container_class', $classes, $class );
		$classes = array_unique( $classes );

		echo join( ' ', $classes ); // WPCS: XSS ok.

	}
endif;
